Name:           jinput
Version:        2.0.6
Release:        6.20130309svn%{?dist}
Summary:        Java Game Controller API

Group:          Development/Libraries
License:        BSD
URL:            http://java.net/projects/jinput
# Upstream only provides subversion checkout or nightly build.
# Also, some (non-Linux) plugin code is non-free.  As long as we are deleting
# non-free plugins, we also delete plugins for non-Linux operating systems.
# Create the source tarball as follows:
# svn export -r 251 https://svn.java.net/svn/jinput~svn/trunk jinput-2.0.6
# rm -rf jinput-2.0.6/plugins/{OSX,windows,wintab}
# tar cJf jinput-2.0.6.tar.xz jinput-2.0.6
Source0:        %{name}-%{version}.tar.xz
# Fedora-specific patch: will not be sent upstream.  Remove build.xml rules
# for building non-free plugin code.
Patch0:         001_jinput_build.patch
# Fedora-specific patch: will not be sent upstream.  Do not strip the native
# library.
Patch1:         002_jinput_dontstripso.patch
# Fedora-specific patch: will not be sent upstream.  Load the shared library
# from the Fedora-mandated location.
Patch2:         003_jinput_usesystemload.patch
# Patch from http://java.net/jira/browse/JINPUT-44 to not access usage bits,
# which are not supported in current Linux kernels
Patch3:         004_jinput_usagebits.patch

BuildRequires:  ant
BuildRequires:  java-devel
BuildRequires:  jpackage-utils
BuildRequires:  jutils
BuildRequires:  jutils-javadoc

Requires:       java 
Requires:       jpackage-utils
Requires:       jutils

%description
jinput is an implementation of an API for game controller discovery and
polled input.  It is part of a suite of open-source technologies
initiated by the Game Technology Group at Sun Microsystems with the
intention of making the development of high performance games in Java a
reality.  The API itself is pure Java and presents a platform-neutral,
completely portable model of controller discovery and polling.  It can
handle arbitrary controllers and returns both human and machine
understandable descriptions of the inputs available.

%package javadoc
Summary:        Javadocs for %{name}
Group:          Documentation
Requires:       %{name} = %{version}-%{release}
Requires:       jutils-javadoc
BuildArch:      noarch

%description javadoc
This package contains the API documentation for %{name}.

%prep
%setup -q
%patch0
%patch1
%patch2
%patch3

# Don't use prebuilt jars
rm -f lib/*.jar
build-jar-repository -s -p lib jutils

# Fix the version string in the POMs
sed -i 's/@VERSION@/%{version}/' jinput.pom jinput-platform.pom

# Use Fedora's CFLAGS
sed -i "s/-O2 -Wall/$RPM_OPT_FLAGS/" plugins/linux/src/native/build.xml

%build
# Get the latest definitions from <linux/input.h>
ant -f plugins/linux/src/native/build.xml createNativeDefinitions.java

# Build
ant dist

# The ant target to build javadocs has several problems.  It looks for the
# jutils jar in the wrong place.  It doesn't link to the jutils javadocs.
# It creates distinct sets of javadoc pages for the coreAPI and for the
# plugins, where we would like all of the pages to be in a single javadoc
# package.  We can solve all but the last with a bit of judicious hacking in
# the appropriate build.xml files, but that last point is difficult to address
# without resulting in broken links from the plugin pages to the coreAPI pages.
# Therefore, we throw up our hands in despair and do this instead:
javadoc -d javadoc -classpath lib/jutils.jar:dist/jinput.jar -package \
  -sourcepath plugins/awt/src:plugins/linux/src/java:coreAPI/src/java \
  -link %{_javadocdir}/jutils net.java.games.input

%install
# jar
install -Dp -m 644 dist/%{name}.jar $RPM_BUILD_ROOT%{_jnidir}/%{name}.jar

# jni
install -Dp -m 755 dist/libjinput* \
    $RPM_BUILD_ROOT%{_libdir}/%{name}/libjinput.so
ln -s ../../..%{_jnidir}/%{name}.jar $RPM_BUILD_ROOT%{_libdir}/%{name}/

# javadoc
mkdir -p $RPM_BUILD_ROOT%{_javadocdir}
cp -a javadoc $RPM_BUILD_ROOT%{_javadocdir}/%{name}

# pom
install -d -m 755 $RPM_BUILD_ROOT%{_mavenpomdir}
install -pm 644 jinput-platform.pom  \
    $RPM_BUILD_ROOT%{_mavenpomdir}/JPP-%{name}-platform.pom
install -pm 644 jinput.pom $RPM_BUILD_ROOT%{_mavenpomdir}/JPP-%{name}.pom

%add_maven_depmap
%add_maven_depmap JPP-%{name}-platform.pom 

%check
ant versiontest

%files
%doc README.txt 
%{_jnidir}/%{name}.jar
%{_mavenpomdir}/*
%{_mavendepmapfragdir}/*
%{_libdir}/%{name}

%files javadoc
%{_javadocdir}/%{name}

%changelog
* Sat Aug 03 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.0.6-6.20130309svn
- Rebuilt for https://fedoraproject.org/wiki/Fedora_20_Mass_Rebuild

* Mon Mar 11 2013 Jerry James <loganjerry@gmail.com> - 2.0.6-5.20130309svn
- Update to latest subversion snapshot for support for more controller keys

* Thu Mar  7 2013 Jerry James <loganjerry@gmail.com> - 2.0.6-4.20130225svn
- Update to latest subversion snapshot
- Patch the POM to exclude dependencies on the Windows and OSX plugins

* Thu Feb 14 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.0.6-3.20110801svn
- Rebuilt for https://fedoraproject.org/wiki/Fedora_19_Mass_Rebuild

* Thu Jul 19 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.0.6-2.20110801svn
- Rebuilt for https://fedoraproject.org/wiki/Fedora_18_Mass_Rebuild

* Thu Feb  2 2012 Jerry James <loganjerry@gmail.com> - 2.0.6-1.20110801svn
- Add patch for missing USAGE bits in the Linux kernel
- Don't build the OSX plugin
- Combine javadocs into one place and fix broken links

* Tue Jul 19 2011 Guido Grazioli <guido.grazioli@gmail.com> - 2.0.6-1.20110719svn
- Initial packaging
